@@ -108,11 +108,11 @@ complementi(x)
      GEN x;
 {int l = lgef(x);
  GEN u = cgeti(l);
- unsigned long * v ;
- unsigned long *w ;
+ unsigned plong * v ;
+ unsigned plong *w ;
 
- MP_START_LOW(w,(unsigned long *)x,l);
- MP_START_LOW(v,(unsigned long *)u,l);
+ MP_START_LOW(w,(unsigned plong *)x,l);
+ MP_START_LOW(v,(unsigned plong *)u,l);
  setlgef(u,l);
  setsigne(u,1);
  l -= MP_CODE_WORDS;
@@ -126,7 +126,7 @@ complementi(x)
  
 object big_log_op(x0,y0,op)
 object x0,y0;
- long (*op)();     
+ plong (*op)();     
 { int leadx,leady;
   int result_length;
   int lgx,lgy;
@@ -761,13 +761,13 @@ siLbit_array_op()
 	if (type_of(x) == t_bitvector) {
 		d = x->bv.bv_dim;
 		xp = x->bv.bv_self;
-		xo = x->bv.bv_offset;
+		xo = BV_OFFSET(x);
 		if (type_of(y) != t_bitvector)
 			goto ERROR;
 		if (d != y->bv.bv_dim)
 			goto ERROR;
 		yp = y->bv.bv_self;
-		yo = y->bv.bv_offset;
+		yo = BV_OFFSET(y);
 		if (r == Ct)
 			r = x;
 		if (r != Cnil) {
@@ -775,14 +775,14 @@ siLbit_array_op()
 				goto ERROR;
 			if (r->bv.bv_dim != d)
 				goto ERROR;
-			i = (r->bv.bv_self - xp)*8 + (r->bv.bv_offset - xo);
+			i = (r->bv.bv_self - xp)*8 + (BV_OFFSET(r) - xo);
 			if (i > 0 && i < d || i < 0 && -i < d) {
 				r0 = r;
 				r = Cnil;
 				replace = TRUE;
 				goto L1;
 			}
-			i = (r->bv.bv_self - yp)*8 + (r->bv.bv_offset - yo);
+			i = (r->bv.bv_self - yp)*8 + (BV_OFFSET(r) - yo);
 			if (i > 0 && i < d || i < 0 && -i < d) {
 				r0 = r;
 				r = Cnil;
@@ -809,7 +809,7 @@ siLbit_array_op()
 			goto ERROR;
 		d = x->a.a_dim;
 		xp = x->bv.bv_self;
-		xo = x->bv.bv_offset;
+		xo = BV_OFFSET(x);
 		if (type_of(y) != t_array)
 			goto ERROR;
 		if ((enum aelttype)y->a.a_elttype != aet_bit)
@@ -817,7 +817,7 @@ siLbit_array_op()
 		if (x->a.a_rank != y->a.a_rank)
 			goto ERROR;
 		yp = y->bv.bv_self;
-		yo = y->bv.bv_offset;
+		yo = BV_OFFSET(y);
 		for (i = 0;  i < x->a.a_rank;  i++)
 			if (x->a.a_dims[i] != y->a.a_dims[i])
 				goto ERROR;
@@ -833,14 +833,14 @@ siLbit_array_op()
 			for (i = 0;  i < x->a.a_rank;  i++)
 				if (r->a.a_dims[i] != x->a.a_dims[i])
 					goto ERROR;
-			i = (r->bv.bv_self - xp)*8 + (r->bv.bv_offset - xo);
+			i = (r->bv.bv_self - xp)*8 + (BV_OFFSET(r) - xo);
 			if (i > 0 && i < d || i < 0 && -i < d) {
 				r0 = r;
 				r = Cnil;
 				replace = TRUE;
 				goto L2;
 			} 
-			i = (r->bv.bv_self - yp)*8 + (r->bv.bv_offset - yo);
+			i = (r->bv.bv_self - yp)*8 + (BV_OFFSET(r) - yo);
 			if (i > 0 && i < d || i < 0 && -i < d) {
 				r0 = r;
 				r = Cnil;
@@ -862,7 +862,7 @@ siLbit_array_op()
 		}
 	}
 	rp = r->bv.bv_self;
-	ro = r->bv.bv_offset;
+	ro = BV_OFFSET(r);
 	switch(fixint(o)) {
 		case BOOLCLR:	op = b_clr_op;	break;
 		case BOOLSET:	op = b_set_op;	break;
@@ -928,7 +928,7 @@ siLbit_array_op()
 		}
 	}
 	rp = r0->bv.bv_self;
-	ro = r0->bv.bv_offset;
+	ro = BV_OFFSET(r0);
 	for (n = d/8, i = 0;  i <= n;  i++) {
 		if (i == n) {
 			if ((j = d%8) == 0)
