@@ -158,7 +158,15 @@ Ivs_values()
 }
   
 			
-  
+void
+fatal(s,i1,i2)
+     char *s;
+     int i1;
+     int i2;
+{
+  fprintf(stderr,s,i1,i2);
+  exit(1);
+}
   
   
   
